@@ -694,7 +694,7 @@ class Uniqueness:
     def __init__(self, data: pd.DataFrame, table_name: str):
         self.result = {
             'table_name': str,
-            'column_name': str,
+            'column_names': str,
             'quality_type': str,
             'total_rows': int,
             'total_cells': int,
@@ -705,10 +705,10 @@ class Uniqueness:
         }
         self.data = data
         self.result['table_name'] = table_name
-        self.result['column_name'] = data.columns.values.tolist()
+        self.result['column_names'] = data.columns.values.tolist()
         self.result['total_rows'] = len(self.data.index)
         self.result['total_cells'] = len(self.data.index) * len(
-            self.result['column_name']
+            self.result['column_names']
         )
         self.result['total_quality_column_name'] = None
         self.result['total_quality_cells'] = None
@@ -742,7 +742,7 @@ class Uniqueness:
         self.result['quality_type'] = 'UNIQUENESS_non_duplicate_row'
 
         column_true = []
-        for c in self.result['column_name']:
+        for c in self.result['column_names']:
             self.data[c] = self.data[c].apply(
                 lambda x: x.lower() if (isinstance(x, str)) else x
             )
@@ -770,7 +770,7 @@ class Uniqueness:
 
         self.result['total_quality_cells'] = (
             self.result['total_rows'] - count_duplicate
-        ) * len(self.result['column_name'])
+        ) * len(self.result['column_names'])
         self.result['total_quality_cells'] = self.result[
             'total_quality_cells'
         ] - self.custom_rules()
